@@ -15,10 +15,10 @@
 # specific language governing permissions and limitations
 # under the License.
 
-package Search::Elasticsearch::Client::7_0::Direct::Autoscaling;
-$Search::Elasticsearch::Client::7_0::Direct::Autoscaling::VERSION = '7.717';
+package Search::Elasticsearch::Client::8_0::Direct::Autoscaling;
+$Search::Elasticsearch::Client::8_0::Direct::Autoscaling::VERSION = '8.00';
 use Moo;
-with 'Search::Elasticsearch::Client::7_0::Role::API';
+with 'Search::Elasticsearch::Client::8_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 use Search::Elasticsearch::Util qw(parse_params);
 use namespace::clean;
@@ -32,16 +32,16 @@ __PACKAGE__->_install_api('autoscaling');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::7_0::Direct::Autoscaling - Autoscaling feature of Search::Elasticsearch 7.x
+Search::Elasticsearch::Client::8_0::Direct::Autoscaling - Autoscaling feature of Search::Elasticsearch 8.x
 
 =head1 VERSION
 
-version 7.717
+version 8.00
 
 =head2 DESCRIPTION
 
 The full documentation for Autoscaling is available here:
-L<https://www.elastic.co/guide/en/elasticsearch/reference/7.x/autoscaling-apis.html>
+L<https://www.elastic.co/guide/en/elasticsearch/reference/current/autoscaling-apis.html>
 
 =head1 FOLLOW METHODS
 
@@ -65,5 +65,5 @@ This is free software, licensed under:
 
 __END__
 
-# ABSTRACT: Autoscaling feature of Search::Elasticsearch 7.x
+# ABSTRACT: Autoscaling feature of Search::Elasticsearch 8.x
 
