@@ -16,7 +16,7 @@
 # under the License.
 
 package Search::Elasticsearch::Role::API;
-$Search::Elasticsearch::Role::API::VERSION = '7.717';
+$Search::Elasticsearch::Role::API::VERSION = '8.00';
 use Moo::Role;
 requires 'api_version';
 requires 'api';
@@ -34,9 +34,11 @@ our %Handler = (
     enum    => \&_list,
     number  => \&_num,
     int     => \&_num,
+    integer => \&_num,
     float   => \&_num,
     double  => \&_num,
     "number|string" => \&_numOrString,
+    "boolean|long"  => \&_booleanOrLong
 );
 
 #===================================
@@ -89,6 +91,16 @@ sub _numOrString {
     return _string($_[0]);
 }
 
+#===================================
+sub _booleanOrLong {
+#===================================
+    if (looks_like_number($_[0])) {
+        return _num($_[0]);
+    }
+    my $val = _detect_bool(@_);
+    return ( $val && $val ne 'false' ) ? 'true' : 'false';
+}
+
 #===================================
 sub _qs_init {
 #===================================
@@ -123,7 +135,7 @@ Search::Elasticsearch::Role::API - Provides common functionality for API impleme
 
 =head1 VERSION
 
-version 7.717
+version 8.00
 
 =head1 AUTHOR
 
